# pynuvo
Python3 interface implementation for Nuvo zone amplifier
 Initially developed/tested with older Concerto model
*** Should/could also work with any Nuvo amp, via RS-232 serial, such NV-E6D

## Notes
This is for use with [Home-Assistant](http://home-assistant.io)

## Usage
```python

```

